@@ -31,6 +31,7 @@
 #include <glib/gi18n-lib.h>
 #include <clutter/x11/clutter-x11.h>
 #include <gtk/gtk.h>
+#include <garcon/garcon.h>
 
 #include "stage.h"
 #include "types.h"
@@ -226,12 +227,35 @@ static gboolean _xfdashboard_application_initialize_full(XfdashboardApplication
 	GError							*error;
 	ClutterActor					*stage;
 	XfdashboardThemeLayout			*themeLayout;
+#if !GARCON_CHECK_VERSION(0,3,0)
+	const gchar						*desktop;
+#endif
 
 	g_return_val_if_fail(XFDASHBOARD_IS_APPLICATION(self), FALSE);
 
 	priv=self->priv;
 	error=NULL;
 
+	/* Initialize garcon for current desktop environment */
+#if !GARCON_CHECK_VERSION(0,3,0)
+	desktop=g_getenv("XDG_CURRENT_DESKTOP");
+	if(G_LIKELY(desktop==NULL))
+	{
+		/* If we could not determine current desktop environment
+		 * assume Xfce as this application is developed for this DE.
+		 */
+		desktop="XFCE";
+	}
+		/* If desktop enviroment was found but has no name
+		 * set NULL to get all menu items shown.
+		 */
+		else if(*desktop==0) desktop=NULL;
+
+	garcon_set_environment(desktop);
+#else
+	garcon_set_environment_xdg(GARCON_ENVIRONMENT_XFCE);
+#endif
+
 	/* Initialize xfconf */
 	if(!xfconf_init(&error))
 	{
