@@ -27,12 +27,14 @@
 #endif
 
 #include "background.h"
-#include "enums.h"
 
 #include <glib/gi18n-lib.h>
 #include <gdk/gdk.h>
 #include <math.h>
 
+#include "enums.h"
+#include "outline-effect.h"
+
 /* Define this class in GObject system */
 G_DEFINE_TYPE(XfdashboardBackground,
 				xfdashboard_background,
@@ -48,15 +50,18 @@ struct _XfdashboardBackgroundPrivate
 	XfdashboardBackgroundType	type;
 
 	ClutterColor				*fillColor;
+	XfdashboardCorners			fillCorners;
+	gfloat						fillCornersRadius;
 
 	ClutterColor				*outlineColor;
 	gfloat						outlineWidth;
-
-	XfdashboardCorners			corners;
-	gfloat						cornersRadius;
+	XfdashboardBorders			outlineBorders;
+	XfdashboardCorners			outlineCorners;
+	gfloat						outlineCornersRadius;
 
 	/* Instance related */
-	ClutterContent				*canvas;
+	ClutterContent				*fillCanvas;
+	XfdashboardOutlineEffect	*outline;
 	ClutterImage				*image;
 };
 
@@ -67,12 +72,19 @@ enum
 
 	PROP_TYPE,
 
-	PROP_FILL_COLOR,
-	PROP_OUTLINE_COLOR,
-	PROP_OUTLINE_WIDTH,
 	PROP_CORNERS,
 	PROP_CORNERS_RADIUS,
 
+	PROP_FILL_COLOR,
+	PROP_FILL_CORNERS,
+	PROP_FILL_CORNERS_RADIUS,
+
+	PROP_OUTLINE_COLOR,
+	PROP_OUTLINE_WIDTH,
+	PROP_OUTLINE_BORDERS,
+	PROP_OUTLINE_CORNERS,
+	PROP_OUTLINE_CORNERS_RADIUS,
+
 	PROP_IMAGE,
 
 	PROP_LAST
@@ -83,11 +95,11 @@ static GParamSpec* XfdashboardBackgroundProperties[PROP_LAST]={ 0, };
 /* IMPLEMENTATION: Private variables and methods */
 
 /* Rectangle canvas should be redrawn */
-static gboolean _xfdashboard_background_on_draw_canvas(XfdashboardBackground *self,
-														cairo_t *inContext,
-														int inWidth,
-														int inHeight,
-														gpointer inUserData)
+static gboolean _xfdashboard_background_on_draw_fill_canvas(XfdashboardBackground *self,
+																cairo_t *inContext,
+																int inWidth,
+																int inHeight,
+																gpointer inUserData)
 {
 	XfdashboardBackgroundPrivate	*priv;
 
@@ -104,24 +116,24 @@ static gboolean _xfdashboard_background_on_draw_canvas(XfdashboardBackground *se
 
 	cairo_set_operator(inContext, CAIRO_OPERATOR_OVER);
 
-	/* Do nothing if type is none (we should not get here but just in case we do) */
-	if(priv->type==XFDASHBOARD_BACKGROUND_TYPE_NONE) return(CLUTTER_EVENT_PROPAGATE);
+	/* Do nothing if type does not include filling backgrouns */
+	if(!(priv->type & XFDASHBOARD_BACKGROUND_TYPE_FILL)) return(CLUTTER_EVENT_PROPAGATE);
 
 	/* Determine if we should draw rounded corners */
 
 	/* Draw rectangle with or without rounded corners */
 	if((priv->type & XFDASHBOARD_BACKGROUND_TYPE_ROUNDED_CORNERS) && 
-		(priv->corners & XFDASHBOARD_CORNERS_ALL) &&
-		priv->cornersRadius>0.0f)
+		(priv->fillCorners & XFDASHBOARD_CORNERS_ALL) &&
+		priv->fillCornersRadius>0.0f)
 	{
 		/* Determine radius for rounded corners */
 		gdouble						radius;
 
-		radius=MIN(priv->cornersRadius, inWidth/2.0f);
+		radius=MIN(priv->fillCornersRadius, inWidth/2.0f);
 		radius=MIN(radius, inHeight/2.0f);
 
 		/* Top-left */
-		if(priv->corners & XFDASHBOARD_CORNERS_TOP_LEFT)
+		if(priv->fillCorners & XFDASHBOARD_CORNERS_TOP_LEFT)
 		{
 			cairo_move_to(inContext, 0, radius);
 			cairo_arc(inContext, radius, radius, radius, G_PI, G_PI*1.5);
@@ -129,7 +141,7 @@ static gboolean _xfdashboard_background_on_draw_canvas(XfdashboardBackground *se
 			else cairo_move_to(inContext, 0, 0);
 
 		/* Top-right */
-		if(priv->corners & XFDASHBOARD_CORNERS_TOP_RIGHT)
+		if(priv->fillCorners & XFDASHBOARD_CORNERS_TOP_RIGHT)
 		{
 			cairo_line_to(inContext, inWidth-radius, 0);
 			cairo_arc(inContext, inWidth-radius, radius, radius, G_PI*1.5, 0);
@@ -137,7 +149,7 @@ static gboolean _xfdashboard_background_on_draw_canvas(XfdashboardBackground *se
 			else cairo_line_to(inContext, inWidth, 0);
 
 		/* Bottom-right */
-		if(priv->corners & XFDASHBOARD_CORNERS_BOTTOM_RIGHT)
+		if(priv->fillCorners & XFDASHBOARD_CORNERS_BOTTOM_RIGHT)
 		{
 			cairo_line_to(inContext, inWidth, inHeight-radius);
 			cairo_arc(inContext, inWidth-radius, inHeight-radius, radius, 0, G_PI/2.0);
@@ -145,7 +157,7 @@ static gboolean _xfdashboard_background_on_draw_canvas(XfdashboardBackground *se
 			else cairo_line_to(inContext, inWidth, inHeight);
 
 		/* Bottom-left */
-		if(priv->corners & XFDASHBOARD_CORNERS_BOTTOM_LEFT)
+		if(priv->fillCorners & XFDASHBOARD_CORNERS_BOTTOM_LEFT)
 		{
 			cairo_line_to(inContext, radius, inHeight);
 			cairo_arc(inContext, radius, inHeight-radius, radius, G_PI/2.0, G_PI);
@@ -153,7 +165,7 @@ static gboolean _xfdashboard_background_on_draw_canvas(XfdashboardBackground *se
 			else cairo_line_to(inContext, 0, inHeight);
 
 		/* Close to top-left */
-		if(priv->corners & XFDASHBOARD_CORNERS_TOP_LEFT) cairo_line_to(inContext, 0, radius);
+		if(priv->fillCorners & XFDASHBOARD_CORNERS_TOP_LEFT) cairo_line_to(inContext, 0, radius);
 			else cairo_line_to(inContext, 0, 0);
 	}
 		else
@@ -161,26 +173,9 @@ static gboolean _xfdashboard_background_on_draw_canvas(XfdashboardBackground *se
 			cairo_rectangle(inContext, 0, 0, inWidth, inHeight);
 		}
 
-	/* Fill if type requests it */
-	if(priv->type & XFDASHBOARD_BACKGROUND_TYPE_FILL)
-	{
-		/* Set color for filling */
-		if(priv->fillColor) clutter_cairo_set_source_color(inContext, priv->fillColor);
-
-		/* Fill */
-		cairo_fill_preserve(inContext);
-	}
-
-	/* Draw outline if type requests it */
-	if(priv->type & XFDASHBOARD_BACKGROUND_TYPE_OUTLINE)
-	{
-		/* Set up line properties for outline */
-		if(priv->outlineColor) clutter_cairo_set_source_color(inContext, priv->outlineColor);
-		cairo_set_line_width(inContext, priv->outlineWidth);
-
-		/* Draw outline */
-		cairo_stroke_preserve(inContext);
-	}
+	/* Set color for filling and fill canvas */
+	if(priv->fillColor) clutter_cairo_set_source_color(inContext, priv->fillColor);
+	cairo_fill_preserve(inContext);
 
 	/* Done drawing */
 	cairo_close_path(inContext);
@@ -197,10 +192,10 @@ static void _xfdashboard_background_paint_node(ClutterActor *self,
 	ClutterContentIface				*iface;
 
 	/* First draw canvas for background */
-	if(priv->type!=XFDASHBOARD_BACKGROUND_TYPE_NONE)
+	if(priv->type & XFDASHBOARD_BACKGROUND_TYPE_FILL)
 	{
-		iface=CLUTTER_CONTENT_GET_IFACE(priv->canvas);
-		if(iface->paint_content) iface->paint_content(priv->canvas, self, inRootNode);
+		iface=CLUTTER_CONTENT_GET_IFACE(priv->fillCanvas);
+		if(iface->paint_content) iface->paint_content(priv->fillCanvas, self, inRootNode);
 	}
 
 	/* If available draw image for background */
@@ -217,49 +212,6 @@ static void _xfdashboard_background_paint_node(ClutterActor *self,
 	}
 }
 
-/* Get preferred width/height */
-static void _xfdashboard_background_get_preferred_height(ClutterActor *self,
-															gfloat inForWidth,
-															gfloat *outMinHeight,
-															gfloat *outNaturalHeight)
-{
-	XfdashboardBackgroundPrivate	*priv=XFDASHBOARD_BACKGROUND(self)->priv;
-	gfloat							minHeight, naturalHeight;
-	
-	minHeight=naturalHeight=0.0f;
-
-	/* Determine size if any type of rectangle should be drawn */
-	if(priv->type & XFDASHBOARD_BACKGROUND_TYPE_ROUNDED_CORNERS)
-	{
-		naturalHeight=priv->cornersRadius*2.0f;
-	}
-
-	/* Store sizes computed */
-	if(outMinHeight) *outMinHeight=minHeight;
-	if(outNaturalHeight) *outNaturalHeight=naturalHeight;
-}
-
-static void _xfdashboard_background_get_preferred_width(ClutterActor *self,
-														gfloat inForHeight,
-														gfloat *outMinWidth,
-														gfloat *outNaturalWidth)
-{
-	XfdashboardBackgroundPrivate	*priv=XFDASHBOARD_BACKGROUND(self)->priv;
-	gfloat							minWidth, naturalWidth;
-
-	minWidth=naturalWidth=0.0f;
-
-	/* Determine size if any type of rectangle should be drawn */
-	if(priv->type & XFDASHBOARD_BACKGROUND_TYPE_ROUNDED_CORNERS)
-	{
-		naturalWidth=priv->cornersRadius*2.0f;
-	}
-
-	/* Store sizes computed */
-	if(outMinWidth) *outMinWidth=minWidth;
-	if(outNaturalWidth) *outNaturalWidth=naturalWidth;
-}
-
 /* Allocate position and size of actor and its children */
 static void _xfdashboard_background_allocate(ClutterActor *self,
 												const ClutterActorBox *inBox,
@@ -271,7 +223,7 @@ static void _xfdashboard_background_allocate(ClutterActor *self,
 	CLUTTER_ACTOR_CLASS(xfdashboard_background_parent_class)->allocate(self, inBox, inFlags);
 
 	/* Set size of canvas */
-	clutter_canvas_set_size(CLUTTER_CANVAS(priv->canvas),
+	clutter_canvas_set_size(CLUTTER_CANVAS(priv->fillCanvas),
 								clutter_actor_box_get_width(inBox),
 								clutter_actor_box_get_height(inBox));
 }
@@ -284,10 +236,10 @@ static void _xfdashboard_background_dispose(GObject *inObject)
 	/* Release allocated variables */
 	XfdashboardBackgroundPrivate	*priv=XFDASHBOARD_BACKGROUND(inObject)->priv;
 
-	if(priv->canvas)
+	if(priv->fillCanvas)
 	{
-		g_object_unref(priv->canvas);
-		priv->canvas=NULL;
+		g_object_unref(priv->fillCanvas);
+		priv->fillCanvas=NULL;
 	}
 
 	if(priv->image)
@@ -308,6 +260,12 @@ static void _xfdashboard_background_dispose(GObject *inObject)
 		priv->outlineColor=NULL;
 	}
 
+	if(priv->outline)
+	{
+		g_object_unref(priv->outline);
+		priv->outline=NULL;
+	}
+
 	/* Call parent's class dispose method */
 	G_OBJECT_CLASS(xfdashboard_background_parent_class)->dispose(inObject);
 }
@@ -326,10 +284,26 @@ static void _xfdashboard_background_set_property(GObject *inObject,
 			xfdashboard_background_set_background_type(self, g_value_get_flags(inValue));
 			break;
 
+		case PROP_CORNERS:
+			xfdashboard_background_set_corners(self, g_value_get_flags(inValue));
+			break;
+
+		case PROP_CORNERS_RADIUS:
+			xfdashboard_background_set_corner_radius(self, g_value_get_float(inValue));
+			break;
+
 		case PROP_FILL_COLOR:
 			xfdashboard_background_set_fill_color(self, clutter_value_get_color(inValue));
 			break;
 
+		case PROP_FILL_CORNERS:
+			xfdashboard_background_set_fill_corners(self, g_value_get_flags(inValue));
+			break;
+
+		case PROP_FILL_CORNERS_RADIUS:
+			xfdashboard_background_set_fill_corner_radius(self, g_value_get_float(inValue));
+			break;
+
 		case PROP_OUTLINE_COLOR:
 			xfdashboard_background_set_outline_color(self, clutter_value_get_color(inValue));
 			break;
@@ -338,12 +312,16 @@ static void _xfdashboard_background_set_property(GObject *inObject,
 			xfdashboard_background_set_outline_width(self, g_value_get_float(inValue));
 			break;
 
-		case PROP_CORNERS:
-			xfdashboard_background_set_corners(self, g_value_get_flags(inValue));
+		case PROP_OUTLINE_BORDERS:
+			xfdashboard_background_set_outline_borders(self, g_value_get_flags(inValue));
 			break;
 
-		case PROP_CORNERS_RADIUS:
-			xfdashboard_background_set_corner_radius(self, g_value_get_float(inValue));
+		case PROP_OUTLINE_CORNERS:
+			xfdashboard_background_set_outline_corners(self, g_value_get_flags(inValue));
+			break;
+
+		case PROP_OUTLINE_CORNERS_RADIUS:
+			xfdashboard_background_set_outline_corner_radius(self, g_value_get_float(inValue));
 			break;
 
 		case PROP_IMAGE:
@@ -374,6 +352,14 @@ static void _xfdashboard_background_get_property(GObject *inObject,
 			clutter_value_set_color(outValue, priv->fillColor);
 			break;
 
+		case PROP_FILL_CORNERS:
+			g_value_set_flags(outValue, priv->fillCorners);
+			break;
+
+		case PROP_FILL_CORNERS_RADIUS:
+			g_value_set_float(outValue, priv->fillCornersRadius);
+			break;
+
 		case PROP_OUTLINE_COLOR:
 			clutter_value_set_color(outValue, priv->outlineColor);
 			break;
@@ -382,12 +368,16 @@ static void _xfdashboard_background_get_property(GObject *inObject,
 			g_value_set_float(outValue, priv->outlineWidth);
 			break;
 
-		case PROP_CORNERS:
-			g_value_set_flags(outValue, priv->corners);
+		case PROP_OUTLINE_BORDERS:
+			g_value_set_flags(outValue, priv->outlineBorders);
 			break;
 
-		case PROP_CORNERS_RADIUS:
-			g_value_set_float(outValue, priv->cornersRadius);
+		case PROP_OUTLINE_CORNERS:
+			g_value_set_flags(outValue, priv->outlineCorners);
+			break;
+
+		case PROP_OUTLINE_CORNERS_RADIUS:
+			g_value_set_float(outValue, priv->outlineCornersRadius);
 			break;
 
 		case PROP_IMAGE:
@@ -416,8 +406,6 @@ static void xfdashboard_background_class_init(XfdashboardBackgroundClass *klass)
 	gobjectClass->get_property=_xfdashboard_background_get_property;
 
 	clutterActorClass->paint_node=_xfdashboard_background_paint_node;
-	clutterActorClass->get_preferred_width=_xfdashboard_background_get_preferred_width;
-	clutterActorClass->get_preferred_height=_xfdashboard_background_get_preferred_height;
 	clutterActorClass->allocate=_xfdashboard_background_allocate;
 
 	/* Set up private structure */
@@ -430,21 +418,53 @@ static void xfdashboard_background_class_init(XfdashboardBackgroundClass *klass)
 							_("Background type"),
 							XFDASHBOARD_TYPE_BACKGROUND_TYPE,
 							XFDASHBOARD_BACKGROUND_TYPE_NONE,
-							G_PARAM_READWRITE);
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+	XfdashboardBackgroundProperties[PROP_CORNERS]=
+		g_param_spec_flags("corners",
+							_("Corners"),
+							_("Determines which corners are rounded for background and outline"),
+							XFDASHBOARD_TYPE_CORNERS,
+							XFDASHBOARD_CORNERS_ALL,
+							G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
+
+	XfdashboardBackgroundProperties[PROP_CORNERS_RADIUS]=
+		g_param_spec_float("corner-radius",
+							_("Corner radius"),
+							_("Radius of rounded corners for background and outline"),
+							0.0f, G_MAXFLOAT,
+							0.0f,
+							G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardBackgroundProperties[PROP_FILL_COLOR]=
 		clutter_param_spec_color("background-fill-color",
 									_("Background fill color"),
 									_("Color to fill background with"),
 									CLUTTER_COLOR_Black,
-									G_PARAM_READWRITE);
+									G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+	XfdashboardBackgroundProperties[PROP_FILL_CORNERS]=
+		g_param_spec_flags("background-fill-corners",
+							_("Fill corners"),
+							_("Determines which corners are rounded at background"),
+							XFDASHBOARD_TYPE_CORNERS,
+							XFDASHBOARD_CORNERS_ALL,
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+	XfdashboardBackgroundProperties[PROP_FILL_CORNERS_RADIUS]=
+		g_param_spec_float("background-fill-corner-radius",
+							_("Corner radius"),
+							_("Radius of rounded corners of background"),
+							0.0f, G_MAXFLOAT,
+							0.0f,
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardBackgroundProperties[PROP_OUTLINE_COLOR]=
 		clutter_param_spec_color("outline-color",
 									_("Outline color"),
 									_("Color to draw outline with"),
 									CLUTTER_COLOR_White,
-									G_PARAM_READWRITE);
+									G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardBackgroundProperties[PROP_OUTLINE_WIDTH]=
 		g_param_spec_float("outline-width",
@@ -452,40 +472,53 @@ static void xfdashboard_background_class_init(XfdashboardBackgroundClass *klass)
 							_("Width of line used to draw outline"),
 							0.0f, G_MAXFLOAT,
 							1.0f,
-							G_PARAM_READWRITE);
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
-	XfdashboardBackgroundProperties[PROP_CORNERS]=
-		g_param_spec_flags("corners",
-							_("Corners"),
-							_("Determines which corners are rounded"),
+	XfdashboardBackgroundProperties[PROP_OUTLINE_BORDERS]=
+		g_param_spec_flags("outline-borders",
+							_("Outline borders"),
+							_("Determines which sides of border of outline should be drawn"),
+							XFDASHBOARD_TYPE_BORDERS,
+							XFDASHBOARD_BORDERS_ALL,
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+	XfdashboardBackgroundProperties[PROP_OUTLINE_CORNERS]=
+		g_param_spec_flags("outline-corners",
+							_("Outline corners"),
+							_("Determines which corners are rounded at outline"),
 							XFDASHBOARD_TYPE_CORNERS,
 							XFDASHBOARD_CORNERS_ALL,
-							G_PARAM_READWRITE);
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
-	XfdashboardBackgroundProperties[PROP_CORNERS_RADIUS]=
-		g_param_spec_float("corner-radius",
-							_("Corner radius"),
-							_("Radius of rounded corners"),
+	XfdashboardBackgroundProperties[PROP_OUTLINE_CORNERS_RADIUS]=
+		g_param_spec_float("outline-corner-radius",
+							_("Outline corner radius"),
+							_("Radius of rounded corners of outline"),
 							0.0f, G_MAXFLOAT,
 							0.0f,
-							G_PARAM_READWRITE);
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardBackgroundProperties[PROP_IMAGE]=
 		g_param_spec_object("image",
 							_("Image"),
 							_("Image to draw as background"),
 							CLUTTER_TYPE_IMAGE,
-							G_PARAM_READWRITE);
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	g_object_class_install_properties(gobjectClass, PROP_LAST, XfdashboardBackgroundProperties);
 
 	/* Define stylable properties */
 	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_TYPE]);
-	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_FILL_COLOR]);
-	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_OUTLINE_COLOR]);
-	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_OUTLINE_WIDTH]);
 	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_CORNERS]);
 	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_CORNERS_RADIUS]);
+	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_FILL_COLOR]);
+	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_FILL_CORNERS]);
+	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_FILL_CORNERS_RADIUS]);
+	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_OUTLINE_COLOR]);
+	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_OUTLINE_WIDTH]);
+	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_OUTLINE_BORDERS]);
+	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_OUTLINE_CORNERS]);
+	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_OUTLINE_CORNERS_RADIUS]);
 	xfdashboard_actor_install_stylable_property(actorClass, XfdashboardBackgroundProperties[PROP_IMAGE]);
 }
 
@@ -503,12 +536,19 @@ static void xfdashboard_background_init(XfdashboardBackground *self)
 
 	/* Set up default values */
 	priv->type=XFDASHBOARD_BACKGROUND_TYPE_NONE;
-	priv->canvas=clutter_canvas_new();
+
+	priv->fillCanvas=clutter_canvas_new();
 	priv->fillColor=clutter_color_copy(CLUTTER_COLOR_Black);
+	priv->fillCorners=XFDASHBOARD_CORNERS_ALL;
+	priv->fillCornersRadius=0.0f;
+
+	priv->outline=XFDASHBOARD_OUTLINE_EFFECT(g_object_ref(xfdashboard_outline_effect_new()));
 	priv->outlineColor=clutter_color_copy(CLUTTER_COLOR_White);
 	priv->outlineWidth=1.0f;
-	priv->corners=XFDASHBOARD_CORNERS_ALL;
-	priv->cornersRadius=0.0f;
+	priv->outlineCorners=XFDASHBOARD_CORNERS_ALL;
+	priv->outlineBorders=XFDASHBOARD_BORDERS_ALL;
+	priv->outlineCornersRadius=0.0f;
+
 	priv->image=NULL;
 
 	/* Set up actor */
@@ -516,8 +556,11 @@ static void xfdashboard_background_init(XfdashboardBackground *self)
 												CLUTTER_SCALING_FILTER_TRILINEAR,
 												CLUTTER_SCALING_FILTER_LINEAR);
 
+	clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(priv->outline), FALSE);
+	clutter_actor_add_effect(CLUTTER_ACTOR(self), CLUTTER_EFFECT(priv->outline));
+
 	/* Connect signals */
-	g_signal_connect_swapped(priv->canvas, "draw", G_CALLBACK(_xfdashboard_background_on_draw_canvas), self);
+	g_signal_connect_swapped(priv->fillCanvas, "draw", G_CALLBACK(_xfdashboard_background_on_draw_fill_canvas), self);
 }
 
 /* IMPLEMENTATION: Public API */
@@ -541,6 +584,7 @@ XfdashboardBackgroundType xfdashboard_background_get_background_type(Xfdashboard
 void xfdashboard_background_set_background_type(XfdashboardBackground *self, const XfdashboardBackgroundType inType)
 {
 	XfdashboardBackgroundPrivate	*priv;
+	gboolean						enableOutline;
 
 	g_return_if_fail(XFDASHBOARD_IS_BACKGROUND(self));
 
@@ -551,13 +595,42 @@ void xfdashboard_background_set_background_type(XfdashboardBackground *self, con
 	{
 		/* Set value */
 		priv->type=inType;
-		clutter_content_invalidate(priv->canvas);
+
+		/* Force redraw of background canvas */
+		clutter_content_invalidate(priv->fillCanvas);
+
+		/* Enable or disable drawing outline */
+		if(inType & XFDASHBOARD_BACKGROUND_TYPE_OUTLINE) enableOutline=TRUE;
+			else enableOutline=FALSE;
+
+		clutter_actor_meta_set_enabled(CLUTTER_ACTOR_META(priv->outline), enableOutline);
 
 		/* Notify about property change */
 		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_TYPE]);
 	}
 }
 
+/* Set radius for rounded corners of background and outline */
+void xfdashboard_background_set_corners(XfdashboardBackground *self, XfdashboardCorners inCorners)
+{
+	g_return_if_fail(XFDASHBOARD_IS_BACKGROUND(self));
+
+	/* Set radius */
+	xfdashboard_background_set_fill_corners(self, inCorners);
+	xfdashboard_background_set_outline_corners(self, inCorners);
+}
+
+/* Set radius for rounded corners of background and outline */
+void xfdashboard_background_set_corner_radius(XfdashboardBackground *self, const gfloat inRadius)
+{
+	g_return_if_fail(XFDASHBOARD_IS_BACKGROUND(self));
+	g_return_if_fail(inRadius>=0.0f);
+
+	/* Set radius */
+	xfdashboard_background_set_fill_corner_radius(self, inRadius);
+	xfdashboard_background_set_outline_corner_radius(self, inRadius);
+}
+
 /* Get/set color to fill background with */
 const ClutterColor* xfdashboard_background_get_fill_color(XfdashboardBackground *self)
 {
@@ -583,13 +656,74 @@ void xfdashboard_background_set_fill_color(XfdashboardBackground *self, const Cl
 		priv->fillColor=clutter_color_copy(inColor);
 
 		/* Invalidate canvas to get it redrawn */
-		if(priv->canvas) clutter_content_invalidate(priv->canvas);
+		if(priv->fillCanvas) clutter_content_invalidate(priv->fillCanvas);
 
 		/* Notify about property change */
 		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_FILL_COLOR]);
 	}
 }
 
+/* Get/set corners to draw rounded when drawing background */
+XfdashboardCorners xfdashboard_background_get_fill_corners(XfdashboardBackground *self)
+{
+	g_return_val_if_fail(XFDASHBOARD_IS_BACKGROUND(self), XFDASHBOARD_CORNERS_NONE);
+
+	return(self->priv->fillCorners);
+}
+
+void xfdashboard_background_set_fill_corners(XfdashboardBackground *self, XfdashboardCorners inCorners)
+{
+	XfdashboardBackgroundPrivate	*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_BACKGROUND(self));
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(priv->fillCorners!=inCorners)
+	{
+		/* Set value */
+		priv->fillCorners=inCorners;
+
+		/* Invalidate canvas to get it redrawn */
+		if(priv->fillCanvas) clutter_content_invalidate(priv->fillCanvas);
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_FILL_CORNERS]);
+	}
+}
+
+/* Get/set radius for rounded corners when drawing background */
+gfloat xfdashboard_background_get_fill_corner_radius(XfdashboardBackground *self)
+{
+	g_return_val_if_fail(XFDASHBOARD_IS_BACKGROUND(self), 0.0f);
+
+	return(self->priv->fillCornersRadius);
+}
+
+void xfdashboard_background_set_fill_corner_radius(XfdashboardBackground *self, const gfloat inRadius)
+{
+	XfdashboardBackgroundPrivate	*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_BACKGROUND(self));
+	g_return_if_fail(inRadius>=0.0f);
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(priv->fillCornersRadius!=inRadius)
+	{
+		/* Set value */
+		priv->fillCornersRadius=inRadius;
+
+		/* Invalidate canvas to get it redrawn */
+		if(priv->fillCanvas) clutter_content_invalidate(priv->fillCanvas);
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_FILL_CORNERS_RADIUS]);
+	}
+}
+
 /* Get/set color to draw outline with */
 const ClutterColor* xfdashboard_background_get_outline_color(XfdashboardBackground *self)
 {
@@ -614,8 +748,8 @@ void xfdashboard_background_set_outline_color(XfdashboardBackground *self, const
 		if(priv->outlineColor) clutter_color_free(priv->outlineColor);
 		priv->outlineColor=clutter_color_copy(inColor);
 
-		/* Invalidate canvas to get it redrawn */
-		if(priv->canvas) clutter_content_invalidate(priv->canvas);
+		/* Update effect */
+		if(priv->outline) xfdashboard_outline_effect_set_color(priv->outline, inColor);
 
 		/* Notify about property change */
 		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_OUTLINE_COLOR]);
@@ -645,23 +779,23 @@ void xfdashboard_background_set_outline_width(XfdashboardBackground *self, const
 		/* Set value */
 		priv->outlineWidth=inWidth;
 
-		/* Invalidate canvas to get it redrawn */
-		if(priv->canvas) clutter_content_invalidate(priv->canvas);
+		/* Update effect */
+		if(priv->outline) xfdashboard_outline_effect_set_width(priv->outline, inWidth);
 
 		/* Notify about property change */
 		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_OUTLINE_WIDTH]);
 	}
 }
 
-/* Get/set corners to draw rounded when drawing a rectangle */
-XfdashboardCorners xfdashboard_background_get_corners(XfdashboardBackground *self)
+/* Get/set sides of border of outline to draw rounded when drawing outline */
+XfdashboardBorders xfdashboard_background_get_outline_borders(XfdashboardBackground *self)
 {
 	g_return_val_if_fail(XFDASHBOARD_IS_BACKGROUND(self), XFDASHBOARD_CORNERS_NONE);
 
-	return(self->priv->corners);
+	return(self->priv->outlineCorners);
 }
 
-void xfdashboard_background_set_corners(XfdashboardBackground *self, XfdashboardCorners inCorners)
+void xfdashboard_background_set_outline_borders(XfdashboardBackground *self, XfdashboardBorders inBorders)
 {
 	XfdashboardBackgroundPrivate	*priv;
 
@@ -670,28 +804,58 @@ void xfdashboard_background_set_corners(XfdashboardBackground *self, Xfdashboard
 	priv=self->priv;
 
 	/* Set value if changed */
-	if(priv->corners!=inCorners)
+	if(priv->outlineBorders!=inBorders)
 	{
 		/* Set value */
-		priv->corners=inCorners;
+		priv->outlineBorders=inBorders;
 
-		/* Invalidate canvas to get it redrawn */
-		if(priv->canvas) clutter_content_invalidate(priv->canvas);
+		/* Update effect */
+		if(priv->outline) xfdashboard_outline_effect_set_borders(priv->outline, inBorders);
 
 		/* Notify about property change */
-		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_CORNERS]);
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_OUTLINE_BORDERS]);
 	}
 }
 
-/* Get/set radius for rounded corners when drawing a rectangle */
-gfloat xfdashboard_background_get_corner_radius(XfdashboardBackground *self)
+/* Get/set corners to draw rounded when drawing outline */
+XfdashboardCorners xfdashboard_background_get_outline_corners(XfdashboardBackground *self)
+{
+	g_return_val_if_fail(XFDASHBOARD_IS_BACKGROUND(self), XFDASHBOARD_CORNERS_NONE);
+
+	return(self->priv->outlineCorners);
+}
+
+void xfdashboard_background_set_outline_corners(XfdashboardBackground *self, XfdashboardCorners inCorners)
+{
+	XfdashboardBackgroundPrivate	*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_BACKGROUND(self));
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(priv->outlineCorners!=inCorners)
+	{
+		/* Set value */
+		priv->outlineCorners=inCorners;
+
+		/* Update effect */
+		if(priv->outline) xfdashboard_outline_effect_set_corners(priv->outline, inCorners);
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_OUTLINE_CORNERS]);
+	}
+}
+
+/* Get/set radius for rounded corners when drawing outline */
+gfloat xfdashboard_background_get_outline_corner_radius(XfdashboardBackground *self)
 {
 	g_return_val_if_fail(XFDASHBOARD_IS_BACKGROUND(self), 0.0f);
 
-	return(self->priv->cornersRadius);
+	return(self->priv->fillCornersRadius);
 }
 
-void xfdashboard_background_set_corner_radius(XfdashboardBackground *self, const gfloat inRadius)
+void xfdashboard_background_set_outline_corner_radius(XfdashboardBackground *self, const gfloat inRadius)
 {
 	XfdashboardBackgroundPrivate	*priv;
 
@@ -701,16 +865,16 @@ void xfdashboard_background_set_corner_radius(XfdashboardBackground *self, const
 	priv=self->priv;
 
 	/* Set value if changed */
-	if(priv->cornersRadius!=inRadius)
+	if(priv->outlineCornersRadius!=inRadius)
 	{
 		/* Set value */
-		priv->cornersRadius=inRadius;
+		priv->outlineCornersRadius=inRadius;
 
-		/* Invalidate canvas to get it redrawn */
-		if(priv->canvas) clutter_content_invalidate(priv->canvas);
+		/* Update effect */
+		if(priv->outline) xfdashboard_outline_effect_set_corner_radius(priv->outline, inRadius);
 
 		/* Notify about property change */
-		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_CORNERS_RADIUS]);
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardBackgroundProperties[PROP_OUTLINE_CORNERS_RADIUS]);
 	}
 }
 
