@@ -41,6 +41,7 @@
 
 #include "marshal.h"
 #include "actor.h"
+#include "stylable.h"
 
 /* Define this class in GObject system */
 G_DEFINE_TYPE(XfdashboardClickAction,
@@ -127,8 +128,8 @@ static void _xfdashboard_click_action_set_pressed(XfdashboardClickAction *self,
 		actor=clutter_actor_meta_get_actor(CLUTTER_ACTOR_META(self));
 		if(XFDASHBOARD_IS_ACTOR(actor))
 		{
-			if(priv->isPressed) xfdashboard_actor_add_style_pseudo_class(XFDASHBOARD_ACTOR(actor), "pressed");
-				else xfdashboard_actor_remove_style_pseudo_class(XFDASHBOARD_ACTOR(actor), "pressed");
+			if(priv->isPressed) xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(actor), "pressed");
+				else xfdashboard_stylable_remove_pseudo_class(XFDASHBOARD_STYLABLE(actor), "pressed");
 		}
 
 		/* Notify about property change */
@@ -140,7 +141,6 @@ static void _xfdashboard_click_action_set_pressed(XfdashboardClickAction *self,
 static void _xfdashboard_click_action_set_held(XfdashboardClickAction *self, gboolean isHeld)
 {
 	XfdashboardClickActionPrivate	*priv;
-	ClutterActor					*actor;
 
 	g_return_if_fail(XFDASHBOARD_IS_CLICK_ACTION(self));
 
@@ -154,14 +154,6 @@ static void _xfdashboard_click_action_set_held(XfdashboardClickAction *self, gbo
 		/* Set value */
 		priv->isHeld=isHeld;
 
-		/* Style state */
-		actor=clutter_actor_meta_get_actor(CLUTTER_ACTOR_META(self));
-		if(XFDASHBOARD_IS_ACTOR(actor))
-		{
-			if(priv->isPressed) xfdashboard_actor_add_style_pseudo_class(XFDASHBOARD_ACTOR(actor), "press-held");
-				else xfdashboard_actor_remove_style_pseudo_class(XFDASHBOARD_ACTOR(actor), "press-held");
-		}
-
 		/* Notify about property change */
 		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardClickActionProperties[PROP_HELD]);
 	}
@@ -593,14 +585,14 @@ static void xfdashboard_click_action_class_init(XfdashboardClickActionClass *kla
 								_("Pressed"),
 								_("Whether the clickable should be in pressed state"),
 								FALSE,
-								G_PARAM_READABLE);
+								G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardClickActionProperties[PROP_HELD]=
 		g_param_spec_boolean("held",
 								_("Held"),
 								_("Whether the clickable has a grab"),
 								FALSE,
-								G_PARAM_READABLE);
+								G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardClickActionProperties[PROP_LONG_PRESS_DURATION]=
 		g_param_spec_int("long-press-duration",
@@ -609,7 +601,7 @@ static void xfdashboard_click_action_class_init(XfdashboardClickActionClass *kla
 							-1,
 							G_MAXINT,
 							-1,
-							G_PARAM_READWRITE);
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardClickActionProperties[PROP_LONG_PRESS_THRESHOLD]=
 		g_param_spec_int("long-press-threshold",
@@ -618,7 +610,7 @@ static void xfdashboard_click_action_class_init(XfdashboardClickActionClass *kla
 							-1,
 							G_MAXINT,
 							-1,
-							G_PARAM_READWRITE);
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	g_object_class_install_properties(gobjectClass, PROP_LAST, XfdashboardClickActionProperties);
 
