@@ -29,6 +29,8 @@
 
 #include <glib/gi18n-lib.h>
 
+#include "stylable.h"
+
 /* Define this class in GObject system */
 G_DEFINE_TYPE(XfdashboardToggleButton,
 				xfdashboard_toggle_button,
@@ -42,6 +44,7 @@ struct _XfdashboardToggleButtonPrivate
 {
 	/* Properties related */
 	gboolean		toggleState;
+	gboolean		autoToggleOnClick;
 };
 
 /* Properties */
@@ -50,6 +53,7 @@ enum
 	PROP_0,
 
 	PROP_TOGGLE_STATE,
+	PROP_AUTO_TOGGLE,
 
 	PROP_LAST
 };
@@ -85,8 +89,11 @@ static void _xfdashboard_toggle_button_clicked(XfdashboardButton *inButton)
 		XFDASHBOARD_BUTTON_CLASS(xfdashboard_toggle_button_parent_class)->clicked(inButton);
 	}
 
-	/* Set new toggle state */
-	xfdashboard_toggle_button_set_toggle_state(self, !priv->toggleState);
+	/* Set new toggle state if "auto-toggle" (on click) is set */
+	if(priv->autoToggleOnClick)
+	{
+		xfdashboard_toggle_button_set_toggle_state(self, !priv->toggleState);
+	}
 }
 
 /* IMPLEMENTATION: GObject */
@@ -137,8 +144,8 @@ static void _xfdashboard_toggle_button_get_property(GObject *inObject,
  */
 static void xfdashboard_toggle_button_class_init(XfdashboardToggleButtonClass *klass)
 {
-	XfdashboardButtonClass	*buttonClass=XFDASHBOARD_BUTTON_CLASS(klass);
-	GObjectClass			*gobjectClass=G_OBJECT_CLASS(klass);
+	XfdashboardButtonClass			*buttonClass=XFDASHBOARD_BUTTON_CLASS(klass);
+	GObjectClass					*gobjectClass=G_OBJECT_CLASS(klass);
 
 	/* Override functions */
 	gobjectClass->set_property=_xfdashboard_toggle_button_set_property;
@@ -155,7 +162,14 @@ static void xfdashboard_toggle_button_class_init(XfdashboardToggleButtonClass *k
 								_("Toggle state"),
 								_("State of toggle"),
 								FALSE,
-								G_PARAM_READWRITE);
+								G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
+	XfdashboardToggleButtonProperties[PROP_AUTO_TOGGLE]=
+		g_param_spec_boolean("auto-toggle",
+								_("Auto toggle"),
+								_("If set the toggle state will be toggled on each click"),
+								TRUE,
+								G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	g_object_class_install_properties(gobjectClass, PROP_LAST, XfdashboardToggleButtonProperties);
 
@@ -186,6 +200,7 @@ static void xfdashboard_toggle_button_init(XfdashboardToggleButton *self)
 
 	/* Set up default values */
 	priv->toggleState=FALSE;
+	priv->autoToggleOnClick=TRUE;
 }
 
 /* IMPLEMENTATION: Public API */
@@ -247,8 +262,10 @@ void xfdashboard_toggle_button_set_toggle_state(XfdashboardToggleButton *self, g
 		priv->toggleState=inToggleState;
 
 		/* Set style classes */
-		if(priv->toggleState) xfdashboard_actor_add_style_pseudo_class(XFDASHBOARD_ACTOR(self), "toggled");
-			else xfdashboard_actor_remove_style_pseudo_class(XFDASHBOARD_ACTOR(self), "toggled");
+		if(priv->toggleState) xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(self), "toggled");
+			else xfdashboard_stylable_remove_pseudo_class(XFDASHBOARD_STYLABLE(self), "toggled");
+
+		clutter_actor_queue_redraw(CLUTTER_ACTOR(self));
 
 		/* Notify about property change */
 		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardToggleButtonProperties[PROP_TOGGLE_STATE]);
@@ -257,3 +274,30 @@ void xfdashboard_toggle_button_set_toggle_state(XfdashboardToggleButton *self, g
 		g_signal_emit(self, XfdashboardToggleButtonSignals[SIGNAL_TOGGLED], 0);
 	}
 }
+
+/* Get/set auto-toggle (on click) */
+gboolean xfdashboard_toggle_button_get_auto_toggle(XfdashboardToggleButton *self)
+{
+	g_return_val_if_fail(XFDASHBOARD_IS_TOGGLE_BUTTON(self), 0);
+
+	return(self->priv->autoToggleOnClick);
+}
+
+void xfdashboard_toggle_button_set_auto_toggle(XfdashboardToggleButton *self, gboolean inAuto)
+{
+	XfdashboardToggleButtonPrivate	*priv;
+
+	g_return_if_fail(XFDASHBOARD_IS_TOGGLE_BUTTON(self));
+
+	priv=self->priv;
+
+	/* Set value if changed */
+	if(priv->autoToggleOnClick!=inAuto)
+	{
+		/* Set value */
+		priv->autoToggleOnClick=inAuto;
+
+		/* Notify about property change */
+		g_object_notify_by_pspec(G_OBJECT(self), XfdashboardToggleButtonProperties[PROP_AUTO_TOGGLE]);
+	}
+}
