@@ -39,11 +39,16 @@
 #include "live-window.h"
 #include "application-button.h"
 #include "utils.h"
+#include "stylable.h"
+#include "focusable.h"
 
 /* Define this class in GObject system */
-G_DEFINE_TYPE(XfdashboardWorkspaceSelector,
-				xfdashboard_workspace_selector,
-				XFDASHBOARD_TYPE_BACKGROUND)
+static void _xfdashboard_workspace_selector_focusable_iface_init(XfdashboardFocusableInterface *iface);
+
+G_DEFINE_TYPE_WITH_CODE(XfdashboardWorkspaceSelector,
+						xfdashboard_workspace_selector,
+						XFDASHBOARD_TYPE_BACKGROUND,
+						G_IMPLEMENT_INTERFACE(XFDASHBOARD_TYPE_FOCUSABLE, _xfdashboard_workspace_selector_focusable_iface_init))
 
 /* Private structure - access only by public API if needed */
 #define XFDASHBOARD_WORKSPACE_SELECTOR_GET_PRIVATE(obj) \
@@ -433,7 +438,7 @@ static void _xfdashboard_workspace_selector_on_active_workspace_changed(Xfdashbo
 	if(inPrevWorkspace)
 	{
 		liveWorkspace=_xfdashboard_workspace_selector_find_actor_for_workspace(self, inPrevWorkspace);
-		if(liveWorkspace) xfdashboard_actor_remove_style_pseudo_class(XFDASHBOARD_ACTOR(liveWorkspace), "active");
+		if(liveWorkspace) xfdashboard_stylable_remove_pseudo_class(XFDASHBOARD_STYLABLE(liveWorkspace), "active");
 
 		priv->activeWorkspace=NULL;
 	}
@@ -445,7 +450,7 @@ static void _xfdashboard_workspace_selector_on_active_workspace_changed(Xfdashbo
 		priv->activeWorkspace=workspace;
 
 		liveWorkspace=_xfdashboard_workspace_selector_find_actor_for_workspace(self, priv->activeWorkspace);
-		if(liveWorkspace) xfdashboard_actor_add_style_pseudo_class(XFDASHBOARD_ACTOR(liveWorkspace), "active");
+		if(liveWorkspace) xfdashboard_stylable_add_pseudo_class(XFDASHBOARD_STYLABLE(liveWorkspace), "active");
 	}
 }
 
@@ -794,6 +799,90 @@ static void _xfdashboard_workspace_selector_allocate(ClutterActor *inActor,
 	}
 }
 
+/* IMPLEMENTATION: Interface XfdashboardFocusable */
+
+/* Virtual function "handle_key_event" was called */
+static gboolean _xfdashboard_workspace_selector_focusable_handle_key_event(XfdashboardFocusable *inFocusable,
+																			const ClutterEvent *inEvent)
+{
+	XfdashboardWorkspaceSelector			*self;
+	XfdashboardWorkspaceSelectorPrivate		*priv;
+	gint									currentWorkspace;
+	gint									maxWorkspace;
+	XfdashboardWindowTrackerWorkspace		*workspace;
+
+	g_return_val_if_fail(XFDASHBOARD_IS_FOCUSABLE(inFocusable), CLUTTER_EVENT_PROPAGATE);
+	g_return_val_if_fail(XFDASHBOARD_IS_WORKSPACE_SELECTOR(inFocusable), CLUTTER_EVENT_PROPAGATE);
+
+	self=XFDASHBOARD_WORKSPACE_SELECTOR(inFocusable);
+	priv=self->priv;
+
+	/* Handle key events when key was released */
+	if(clutter_event_type(inEvent)==CLUTTER_KEY_RELEASE)
+	{
+		/* Get current and last workspace */
+		currentWorkspace=xfdashboard_window_tracker_workspace_get_number(priv->activeWorkspace);
+		maxWorkspace=xfdashboard_window_tracker_get_workspaces_count(priv->windowTracker);
+
+		/* Change workspace if an arrow key was pressed which makes sense
+		 * for orientation set
+		 */
+		if((priv->orientation==CLUTTER_ORIENTATION_VERTICAL && inEvent->key.keyval==CLUTTER_KEY_Up) ||
+			(priv->orientation==CLUTTER_ORIENTATION_HORIZONTAL && inEvent->key.keyval==CLUTTER_KEY_Left))
+		{
+			/* Activate previous workspace */
+			currentWorkspace--;
+			if(currentWorkspace<0) currentWorkspace=maxWorkspace-1;
+
+			workspace=xfdashboard_window_tracker_get_workspace_by_number(priv->windowTracker, currentWorkspace);
+			xfdashboard_window_tracker_workspace_activate(workspace);
+
+			/* Event handled */
+			return(CLUTTER_EVENT_STOP);
+		}
+			else if((priv->orientation==CLUTTER_ORIENTATION_VERTICAL && inEvent->key.keyval==CLUTTER_KEY_Down) ||
+					(priv->orientation==CLUTTER_ORIENTATION_HORIZONTAL && inEvent->key.keyval==CLUTTER_KEY_Right))
+			{
+				/* Activate next workspace */
+				currentWorkspace++;
+				if(currentWorkspace>=maxWorkspace) currentWorkspace=0;
+
+				workspace=xfdashboard_window_tracker_get_workspace_by_number(priv->windowTracker, currentWorkspace);
+				xfdashboard_window_tracker_workspace_activate(workspace);
+
+				/* Event handled */
+				return(CLUTTER_EVENT_STOP);
+			}
+
+		/* Activate workspace on ENTER */
+		if(inEvent->key.keyval==CLUTTER_KEY_Return ||
+			inEvent->key.keyval==CLUTTER_KEY_KP_Enter ||
+			inEvent->key.keyval==CLUTTER_KEY_ISO_Enter)
+		{
+			/* Active workspace */
+			workspace=xfdashboard_window_tracker_get_workspace_by_number(priv->windowTracker, currentWorkspace);
+			xfdashboard_window_tracker_workspace_activate(workspace);
+
+			/* Quit application */
+			xfdashboard_application_quit();
+
+			/* Event handled */
+			return(CLUTTER_EVENT_STOP);
+		}
+	}
+
+	/* We did not handle this event */
+	return(CLUTTER_EVENT_PROPAGATE);
+}
+
+/* Interface initialization
+ * Set up default functions
+ */
+void _xfdashboard_workspace_selector_focusable_iface_init(XfdashboardFocusableInterface *iface)
+{
+	iface->handle_key_event=_xfdashboard_workspace_selector_focusable_handle_key_event;
+}
+
 /* IMPLEMENTATION: GObject */
 
 /* Dispose this object */
@@ -917,7 +1006,7 @@ static void xfdashboard_workspace_selector_class_init(XfdashboardWorkspaceSelect
 								_("The spacing between children"),
 								0.0, G_MAXFLOAT,
 								0.0,
-								G_PARAM_READWRITE);
+								G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardWorkspaceSelectorProperties[PROP_ORIENTATION]=
 		g_param_spec_enum("orientation",
@@ -925,7 +1014,7 @@ static void xfdashboard_workspace_selector_class_init(XfdashboardWorkspaceSelect
 							_("The orientation to layout children"),
 							CLUTTER_TYPE_ORIENTATION,
 							DEFAULT_ORIENTATION,
-							G_PARAM_READWRITE);
+							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardWorkspaceSelectorProperties[PROP_MAX_SIZE]=
 		g_param_spec_float("max-size",
@@ -933,7 +1022,7 @@ static void xfdashboard_workspace_selector_class_init(XfdashboardWorkspaceSelect
 								_("The maximum size of this actor for opposite direction of orientation"),
 								0.0, G_MAXFLOAT,
 								DEFAULT_MAX_SIZE,
-								G_PARAM_READWRITE);
+								G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardWorkspaceSelectorProperties[PROP_MAX_FRACTION]=
 		g_param_spec_float("max-fraction",
@@ -941,14 +1030,14 @@ static void xfdashboard_workspace_selector_class_init(XfdashboardWorkspaceSelect
 								_("The maximum size of this actor for opposite direction of orientation defined by fraction between 0.0 and 1.0"),
 								0.0, G_MAXFLOAT,
 								DEFAULT_MAX_FRACTION,
-								G_PARAM_READWRITE);
+								G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardWorkspaceSelectorProperties[PROP_USING_FRACTION]=
 		g_param_spec_boolean("using-fraction",
 								_("Using fraction"),
 								_("Flag indicating if maximum size is static or defined by fraction between 0.0 and 1.0"),
 								DEFAULT_USING_FRACTION,
-								G_PARAM_READABLE);
+								G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
 	g_object_class_install_properties(gobjectClass, PROP_LAST, XfdashboardWorkspaceSelectorProperties);
 
